@@ -1,6 +1,6 @@
 #' t-test
 #'
-#' Performs a t-test on each row/column of a the input matrix.
+#' Performs a t-test on each row/column of the input matrix.
 #'
 #' Functions to perform one sample and two sample t-tests for rows/columns of matrices.
 #' Main arguments and results were intentionally matched to the \code{t.test()}
@@ -33,11 +33,11 @@
 #'
 #' @param x numeric matrix.
 #' @param y numeric matrix for the second group of observations.
-#' @param mu true values of the means for the null hypothesis.
-#' A single number or numeric vector with values for each observation.
 #' @param alternative alternative hypothesis to use for each row/column of x.
 #' A single string or a vector with values for each observation.
 #' Values must be one of "two.sided" (default), "greater" or "less".
+#' @param mu true values of the means for the null hypothesis.
+#' A single number or numeric vector with values for each observation.
 #' @param conf.level confidence levels used for the confidence intervals.
 #' A single number or a numeric vector with values for each observation.
 #' All values must be in the range of [0;1].
@@ -80,75 +80,6 @@
 #' @author Karolis Koncevičius
 #' @name ttest
 #' @export
-row_t_onesample <- function(x, alternative="two.sided", mu=0, conf.level=0.95) {
-  force(x)
-
-  if(is.vector(x))
-    x <- matrix(x, nrow=1)
-
-  if(is.data.frame(x) && all(sapply(x, is.numeric)))
-    x <- data.matrix(x)
-
-  assert_numeric_mat_or_vec(x)
-
-
-  if(length(alternative)==1)
-    alternative <- rep(alternative, length.out=nrow(x))
-  assert_character_vec_length(alternative, 1, nrow(x))
-
-  choices <- c("two.sided", "less", "greater")
-  alternative <- choices[pmatch(alternative, choices, duplicates.ok=TRUE)]
-  assert_all_in_set(alternative, choices)
-
-  if(length(mu)==1)
-    mu <- rep(mu, length.out=nrow(x))
-  assert_numeric_vec_length(mu, 1, nrow(x))
-  assert_all_in_range(mu, -Inf, Inf)
-
-  if(length(conf.level)==1)
-    conf.level <- rep(conf.level, length.out=nrow(x))
-  assert_numeric_vec_length(conf.level, 1, nrow(x))
-  assert_all_in_range(conf.level, 0, 1)
-
-
-  mxs <- rowMeans(x, na.rm=TRUE)
-  nxs <- matrixStats::rowCounts(!is.na(x))
-  vxs <- rowSums((x-mxs)^2, na.rm=TRUE) / (nxs-1)
-  dfs <- nxs-1
-  stders <- sqrt(vxs/nxs)
-
-
-  tres <- do_ttest(mxs, mu, stders, alternative, dfs, conf.level)
-
-
-  w1 <- nxs < 2
-  showWarning(w1, 'had less than 2 "x" observations')
-
-  w2 <- !w1 & stders <= 10 * .Machine$double.eps * abs(mxs)
-  showWarning(w2, 'were essentially constant')
-
-
-  tres[w1 | w2,] <- NA
-
-
-  rnames <- rownames(x)
-  if(!is.null(rnames)) rnames <- make.unique(rnames)
-  data.frame(obs=nxs, mean=mxs, var=vxs, stderr=stders, df=dfs,
-             statistic=tres[,1], pvalue=tres[,2], conf.low=tres[,3],
-             conf.high=tres[,4], alternative=alternative, mean.null=mu,
-             conf.level=conf.level, stringsAsFactors=FALSE,
-             row.names=rnames
-             )
-}
-
-#' @rdname ttest
-#' @export
-col_t_onesample <- function(x, alternative="two.sided", mu=0, conf.level=0.95) {
-  row_t_onesample(t(x), alternative=alternative, mu=mu, conf.level=conf.level)
-}
-
-#' @rdname ttest
-#' @export
 row_t_equalvar <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
   force(x)
   force(y)
@@ -183,12 +114,12 @@ row_t_equalvar <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95)
   if(length(mu)==1)
     mu <- rep(mu, length.out=nrow(x))
   assert_numeric_vec_length(mu, 1, nrow(x))
-  assert_all_in_range(mu, -Inf, Inf)
+  assert_all_in_closed_interval(mu, -Inf, Inf)
 
   if(length(conf.level)==1)
     conf.level <- rep(conf.level, length.out=nrow(x))
   assert_numeric_vec_length(conf.level, 1, nrow(x))
-  assert_all_in_range(conf.level, 0, 1)
+  assert_all_in_closed_interval(conf.level, 0, 1)
 
 
   mxs  <- rowMeans(x, na.rm=TRUE)
@@ -239,7 +170,6 @@ row_t_equalvar <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95)
              )
 }
 
-
 #' @rdname ttest
 #' @export
 col_t_equalvar <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
@@ -283,12 +213,12 @@ row_t_welch <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
   if(length(mu)==1)
     mu <- rep(mu, length.out=nrow(x))
   assert_numeric_vec_length(mu, 1, nrow(x))
-  assert_all_in_range(mu, -Inf, Inf)
+  assert_all_in_closed_interval(mu, -Inf, Inf)
 
   if(length(conf.level)==1)
     conf.level <- rep(conf.level, length.out=nrow(x))
   assert_numeric_vec_length(conf.level, 1, nrow(x))
-  assert_all_in_range(conf.level, 0, 1)
+  assert_all_in_closed_interval(conf.level, 0, 1)
 
 
   mxs  <- rowMeans(x, na.rm=TRUE)
@@ -332,7 +262,6 @@ row_t_welch <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
              )
 }
 
-
 #' @rdname ttest
 #' @export
 col_t_welch <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
@@ -340,6 +269,76 @@ col_t_welch <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
 }
 
 
+#' @rdname ttest
+#' @export
+row_t_onesample <- function(x, alternative="two.sided", mu=0, conf.level=0.95) {
+  force(x)
+
+  if(is.vector(x))
+    x <- matrix(x, nrow=1)
+
+  if(is.data.frame(x) && all(sapply(x, is.numeric)))
+    x <- data.matrix(x)
+
+  assert_numeric_mat_or_vec(x)
+
+
+  if(length(alternative)==1)
+    alternative <- rep(alternative, length.out=nrow(x))
+  assert_character_vec_length(alternative, 1, nrow(x))
+
+  choices <- c("two.sided", "less", "greater")
+  alternative <- choices[pmatch(alternative, choices, duplicates.ok=TRUE)]
+  assert_all_in_set(alternative, choices)
+
+  if(length(mu)==1)
+    mu <- rep(mu, length.out=nrow(x))
+  assert_numeric_vec_length(mu, 1, nrow(x))
+  assert_all_in_closed_interval(mu, -Inf, Inf)
+
+  if(length(conf.level)==1)
+    conf.level <- rep(conf.level, length.out=nrow(x))
+  assert_numeric_vec_length(conf.level, 1, nrow(x))
+  assert_all_in_closed_interval(conf.level, 0, 1)
+
+
+  mxs <- rowMeans(x, na.rm=TRUE)
+  nxs <- matrixStats::rowCounts(!is.na(x))
+  vxs <- rowSums((x-mxs)^2, na.rm=TRUE) / (nxs-1)
+  dfs <- nxs-1
+  stders <- sqrt(vxs/nxs)
+
+
+  tres <- do_ttest(mxs, mu, stders, alternative, dfs, conf.level)
+
+
+  w1 <- nxs < 2
+  showWarning(w1, 'had less than 2 "x" observations')
+
+  w2 <- !w1 & stders <= 10 * .Machine$double.eps * abs(mxs)
+  showWarning(w2, 'were essentially constant')
+
+
+  tres[w1 | w2,] <- NA
+
+
+  rnames <- rownames(x)
+  if(!is.null(rnames)) rnames <- make.unique(rnames)
+  data.frame(obs=nxs, mean=mxs, var=vxs, stderr=stders, df=dfs,
+             statistic=tres[,1], pvalue=tres[,2], conf.low=tres[,3],
+             conf.high=tres[,4], alternative=alternative, mean.null=mu,
+             conf.level=conf.level, stringsAsFactors=FALSE,
+             row.names=rnames
+             )
+}
+
+#' @rdname ttest
+#' @export
+col_t_onesample <- function(x, alternative="two.sided", mu=0, conf.level=0.95) {
+  row_t_onesample(t(x), alternative=alternative, mu=mu, conf.level=conf.level)
+}
+
+
 #' @rdname ttest
 #' @export
 row_t_paired <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
@@ -377,12 +376,12 @@ row_t_paired <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
   if(length(mu)==1)
     mu <- rep(mu, length.out=nrow(x))
   assert_numeric_vec_length(mu, 1, nrow(x))
-  assert_all_in_range(mu, -Inf, Inf)
+  assert_all_in_closed_interval(mu, -Inf, Inf)
 
   if(length(conf.level)==1)
     conf.level <- rep(conf.level, length.out=nrow(x))
   assert_numeric_vec_length(conf.level, 1, nrow(x))
-  assert_all_in_range(conf.level, 0, 1)
+  assert_all_in_closed_interval(conf.level, 0, 1)
 
 
   xy <- x-y
@@ -427,7 +426,6 @@ row_t_paired <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
              )
 }
 
-
 #' @rdname ttest
 #' @export
 col_t_paired <- function(x, y, alternative="two.sided", mu=0, conf.level=0.95) {
